ergm.ego.Constructs and checks the list of control parameters for estimation by
ergm.ego.
control.ergm.ego(
ppopsize = c("auto", "samp", "pop"),
ppopsize.mul = 1,
ppop.wt = c("round", "sample"),
stats.wt = c("data", "ppop"),
stats.est = c("asymptotic", "bootstrap", "jackknife", "naive"),
boot.R = 10000,
ergm.control = control.ergm(),
...
)Parameters to determine the size
\(|N'|\) of the pseudopopulation network. ppopsize can be
If the popsize (\(|N|\)) argument is
specified and is different from 1, as if "pop"; otherwise,
as "samp".
set \(|N'|\) based on the sample size: \(|N'|=|S| \times \code{popsize.mul}\)
set \(|N'|\) based on the population size: \(|N'|=|N| \times \code{popsize.mul}\)
set \(|N'|\) directly (popsize.mul
ignored)
network objectuse the specified network as the pseudo-population network directly; use at your own risk
use the specified data frame as the pseudo-population; use at your own risk
The default is to use the same pseudopopulation size as the sample size, but, particularly if there are sampling weights in the data, it should be bigger.
Note that depending on ppop.wt, this may only be an approximate
target specification, with the actual constructed pseudopopulation network
being slightly bigger or smaller.
Because each ego must be represented in the pseuodopopulation
network an integral number of times, if the sample is weighted (or the
target \(|N'|\) calculated from ppopsize and ppopsize.mul is
not a multiple of the sample size), it may not be possible, for a finite
\(|N'|\) to represent each ego exactly according to its relative weight,
and ppop.wt controls how the fractional egos are allocated:
(default) Rather than treating ppopsize as
a hard setting, calculate \(|N'| w_i / w_\cdot\) for each ego \(i\) and
round it to the nearest integer. Then, the \(|N'|\) actually used will be
the sum of these rounded freqencies.
Resample in proportion to \(w_i\).
Weight assigned to each ego's contribution to the ERGM's sufficient statistic:
(default) Use weights \(|N'| w_i / w_\cdot\) for each ego \(i\) as in the data.
Use weights ultimately used in the pseudopopulation network.
Method to be used to estimate the ERGM's sufficient statistics and their variance:
Delta method, as derived by Krivitsky and Morris (2015), assuming the ego weights are sampled alongside the egos.
Delta method, as derived by Krivitsky and Morris (2015), assuming the ego weights are sampled alongside the egos.
Nonparametric bootstrap with bias correction,
resampling egos, using R replications.
Jackknife with bias correction.
"Naive" estimator, assuming that weights are fixed.
Control parameters for the ergm call
to fit the model, constructed by control.ergm.
Not used at this time.
A list with arguments as components.
Pavel N. Krivitsky and Martina Morris. Inference for Social Network Models from Egocentrically-Sampled Data, with Application to Understanding Persistent Racial Disparities in HIV Prevalence in the US. Thechnical Report. National Institute for Applied Statistics Research Australia, University of Wollongong, 2015(05-15). http://niasra.uow.edu.au/publications/UOW190187.html
control.ergm