- formula
A formula object, of the form e
~ <model terms>, where e is a egor
object. See ergm() for details and examples.
For a list of currently implemented egocentric terms for the RHS, see
ergm.ego-terms.
- popsize
The size \(|N|\) of the finite population network
from which the egocentric sample was taken; only affects the
shift in the coefficients of the terms modeling the overall
propensity to have ties. Setting it to 1 (the default)
essentially uses the \(-\log |N'|\) offset on the edges
term. Passing 0 disables network size adjustment and uses the
egocentric sample size; passing I(N) uses the specified
size N (though can be overridden by the ppop
control.ergm.ego() option) and disables network size
adjustment.
- offset.coef
A vector of coefficients for the offset terms.
- constraints
A one-sided formula formula giving
the sample space constraints. See ergm() for
details and examples.
- ...
Additional arguments passed to ergm().
- basis
a value (usually an egor) to override the LHS of the formula.
- control
A control.ergm.ego() control list.
- na.action
How to handle missing actor attributes in egos or alters,
when the terms need them for models that scale.
- na.rm
How to handle missing actor attributes in egos or alters,
when the terms need them for models that do not scale.
- do.fit
Whether to actually call ergm()