ergm Terms Implemented for
egodataThis page describes the ergm terms (and hence network
statistics) for which inference based on egocentrically sampled data is
implemented in ergm.ego package. Other packages may add their own
terms.
For each of these,
please see their respective package's ergm-terms help for meaning and
parameters. The simplest way to do this is usually via ? TERM.
A special-purpose term equivalent to
edges, to house the network-size adjustment offset. This
term is added to the model automatically and should not be used in the model
formula directly.
offset
edges
nodecov
nodefactor
nodematch
nodemix
absdiff
degree
degrange
concurrent
concurrentties
degree1.5
mm
meandeg*
mean.age*
Starred terms are nonscaling, in that while they can be evaluated, some inferential results and standard error calculation methods may not be applicable.
The current recommendation for any package implementing additional
egocentric calculator terms is to create a help file with a name or alias
ergm.egodata-terms, so that help("ergm.egodata-terms") will
list egocentric ERGM terms available from all loaded packages.